@@ -15,21 +15,6 @@
  *                                                                         *
  ***************************************************************************/
 
-// include files for QT
-#include <qdir.h>
-#include <qpainter.h>
-
-// include files for KDE
-#include <kiconloader.h>
-#include <kmenubar.h>
-#include <kstatusbar.h>
-#include <klocale.h>
-#include <kconfig.h>
-#include <kstdaction.h>
-#include <kprinter.h>
-#include <kpopupmenu.h>
-#include <kstandarddirs.h>
-
 // application specific includes
 #include "kmouth.h"
 #include "phraselist.h"
@@ -38,12 +23,38 @@
 #include "optionsdialog.h"
 #include "configwizard.h"
 
+// include files for Qt
+#include <QtCore/QDir>
+#include <QtGui/QPainter>
+#include <QtGui/QPrintDialog>
+#include <QtGui/QMenu>
+
+// include files for KDE
+#include <kxmlguifactory.h>
+#include <kiconloader.h>
+#include <kmenubar.h>
+#include <kstatusbar.h>
+#include <klocale.h>
+#include <kconfig.h>
+#include <kstandardaction.h>
+#include <kmenu.h>
+#include <kstandarddirs.h>
+#include <kglobal.h>
+#include <ktoolbar.h>
+#include <kactioncollection.h>
+#include <kactionmenu.h>
+#include <ktoggleaction.h>
+#include <kstandardshortcut.h>
+#include <kapplication.h>
+#include <kdeprintdialog.h>
+
 #define ID_STATUS_MSG 1
 
-KMouthApp::KMouthApp(QWidget* , const char* name):KMainWindow(0, name)
+KMouthApp::KMouthApp(QWidget* , const char* name):KXmlGuiWindow(0)
 {
+   setObjectName(name);
    isConfigured = false;
-   config=kapp->config();
+   config=KGlobal::config();
 
    ///////////////////////////////////////////////////////////////////
    // call inits to invoke all other construction parts
@@ -56,15 +67,15 @@ KMouthApp::KMouthApp(QWidget* , const char* name):KMainWindow(0, name)
    connect (optionsDialog, SIGNAL(configurationChanged ()),
             phraseList, SLOT(configureCompletion ()));
 
-   phrases = new KActionCollection (this);
+   phrases = new KActionCollection (static_cast<QWidget*>(this));
 
    readOptions();
-   ConfigWizard *wizard = new ConfigWizard (this, "ConfigWizard", config);
+   ConfigWizard *wizard = new ConfigWizard (this, "ConfigWizard", config.data());
    if (wizard->configurationNeeded ()) {
       if (wizard->requestConfiguration ()) {
          isConfigured = true;
          saveOptions();
-         wizard->saveConfig (config);
+         wizard->saveConfig (config.data());
          readOptions();
       }
       else
@@ -82,11 +93,13 @@ KMouthApp::KMouthApp(QWidget* , const char* name):KMainWindow(0, name)
    // disable actions at startup
    fileSaveAs->setEnabled(false);
    filePrint->setEnabled(false);
+
+   printer = 0;
 }
 
 KMouthApp::~KMouthApp()
 {
-
+   delete printer;
 }
 
 bool KMouthApp::configured() {
@@ -95,86 +108,125 @@ bool KMouthApp::configured() {
 
 void KMouthApp::initActions() {
 // The "File" menu
-   fileOpen = new KAction(i18n("&Open as History..."), "phrasehistory_open", KStdAccel::open(), this, SLOT(slotFileOpen()), actionCollection(),"file_open");
-   fileOpen->setStatusText(i18n("Opens an existing file as history"));
+   fileOpen = actionCollection()->addAction("file_open");
+   fileOpen->setIcon(KIcon("phrasehistory_open"));
+   fileOpen->setText(i18n("&Open as History..."));
+   fileOpen->setShortcuts(KStandardShortcut::open());
+   connect(fileOpen, SIGNAL(triggered(bool)), this, SLOT(slotFileOpen()));
+   fileOpen->setToolTip(i18n("Opens an existing file as history"));
    fileOpen->setWhatsThis (i18n("Opens an existing file as history"));
 
-   fileSaveAs = new KAction(i18n("Save &History As..."), "phrasehistory_save", KStdAccel::save(), this, SLOT(slotFileSaveAs()), actionCollection(),"file_save_as");
-   fileSaveAs->setStatusText(i18n("Saves the actual history as..."));
+   fileSaveAs = actionCollection()->addAction("file_save_as");
+   fileSaveAs->setIcon(KIcon("phrasehistory_save"));
+   fileSaveAs->setText(i18n("Save &History As..."));
+   fileSaveAs->setShortcuts(KStandardShortcut::save());
+   connect(fileSaveAs, SIGNAL(triggered(bool)), this, SLOT(slotFileSaveAs()));
+   fileSaveAs->setToolTip(i18n("Saves the actual history as..."));
    fileSaveAs->setWhatsThis (i18n("Saves the actual history as..."));
 
-   filePrint = new KAction(i18n("&Print History..."), "phrasehistory_print", KStdAccel::print(), this, SLOT(slotFilePrint()), actionCollection(),"file_print");
-   filePrint->setStatusText(i18n("Prints out the actual history"));
+   filePrint = actionCollection()->addAction("file_print");
+   filePrint->setIcon(KIcon("phrasehistory_print"));
+   filePrint->setText(i18n("&Print History..."));
+   filePrint->setShortcuts(KStandardShortcut::print());
+   connect(filePrint, SIGNAL(triggered(bool)), this, SLOT(slotFilePrint()));
+   filePrint->setToolTip(i18n("Prints out the actual history"));
    filePrint->setWhatsThis (i18n("Prints out the actual history"));
 
-   fileQuit = KStdAction::quit(this, SLOT(slotFileQuit()), actionCollection());
-   fileQuit->setStatusText(i18n("Quits the application"));
+   fileQuit = KStandardAction::quit(this, SLOT(slotFileQuit()), actionCollection());
+   fileQuit->setToolTip(i18n("Quits the application"));
    fileQuit->setWhatsThis (i18n("Quits the application"));
 
 // The "Edit" menu
-   editCut = KStdAction::cut(phraseList, SLOT(cut()), actionCollection());
-   editCut->setStatusText(i18n("Cuts the selected section and puts it to the clipboard"));
+   editCut = KStandardAction::cut(phraseList, SLOT(cut()), actionCollection());
+   editCut->setToolTip(i18n("Cuts the selected section and puts it to the clipboard"));
    editCut->setWhatsThis (i18n("Cuts the selected section and puts it to the clipboard. If there is some text selected in the edit field it is placed it on the clipboard. Otherwise the selected sentences in the history (if any) are placed on the clipboard."));
 
-   editCopy = KStdAction::copy(phraseList, SLOT(copy()), actionCollection());
-   editCopy->setStatusText(i18n("Copies the selected section to the clipboard"));
+   editCopy = KStandardAction::copy(phraseList, SLOT(copy()), actionCollection());
+   editCopy->setToolTip(i18n("Copies the selected section to the clipboard"));
    editCopy->setWhatsThis (i18n("Copies the selected section to the clipboard. If there is some text selected in the edit field it is copied to the clipboard. Otherwise the selected sentences in the history (if any) are copied to the clipboard."));
 
-   editPaste = KStdAction::paste(phraseList, SLOT(paste()), actionCollection());
-   editPaste->setStatusText(i18n("Pastes the clipboard contents to actual position"));
+   editPaste = KStandardAction::paste(phraseList, SLOT(paste()), actionCollection());
+   editPaste->setToolTip(i18n("Pastes the clipboard contents to actual position"));
    editPaste->setWhatsThis (i18n("Pastes the clipboard contents at the current cursor position into the edit field."));
 
-   editSpeak = new KAction (i18n("&Speak"), "speak", 0, phraseList, SLOT(speak()), actionCollection(),"edit_speak");
-   editSpeak->setStatusText(i18n("Speaks the currently active sentence(s)"));
+   editSpeak = actionCollection()->addAction("edit_speak");
+   editSpeak->setIcon(KIcon("speak"));
+   editSpeak->setText(i18n("&Speak"));
+   connect(editSpeak, SIGNAL(triggered(bool)), phraseList, SLOT(speak()));
+   editSpeak->setToolTip(i18n("Speaks the currently active sentence(s)"));
    editSpeak->setWhatsThis (i18n("Speaks the currently active sentence(s). If there is some text in the edit field it is spoken. Otherwise the selected sentences in the history (if any) are spoken."));
 
 // The "Phrase book" menu
-   phrasebookEdit = new KAction(i18n("&Edit..."), 0, 0, this, SLOT(slotEditPhrasebook()), actionCollection(),"phrasebook_edit");
+   phrasebookEdit = actionCollection()->addAction("phrasebook_edit");
+   phrasebookEdit->setText(i18n("&Edit..."));
+   connect(phrasebookEdit, SIGNAL(triggered(bool)), this, SLOT(slotEditPhrasebook()));
 
 // The "Options" menu
-   viewMenuBar = KStdAction::showMenubar(this, SLOT(slotViewMenuBar()), actionCollection());
-   viewToolBar = KStdAction::showToolbar(this, SLOT(slotViewToolBar()), actionCollection());
-   viewToolBar->setStatusText(i18n("Enables/disables the toolbar"));
-   viewToolBar->setWhatsThis (i18n("Enables/disables the toolbar"));
+   viewMenuBar = KStandardAction::showMenubar(this, SLOT(slotViewMenuBar()), actionCollection());
+   // FIXME: Disable so it will compile.
+   // viewToolBar = KStandardAction::showToolbar(this, SLOT(slotViewToolBar()), actionCollection());
+   // viewToolBar->setToolTip(i18n("Enables/disables the toolbar"));
+   // viewToolBar->setWhatsThis (i18n("Enables/disables the toolbar"));
 
-   viewPhrasebookBar = new KToggleAction (i18n("Show P&hrasebook Bar"), 0, 0, this, SLOT(slotViewPhrasebookBar()), actionCollection(), "showPhrasebookBar");
-   viewPhrasebookBar->setStatusText(i18n("Enables/disables the phrasebook bar"));
+   viewPhrasebookBar = actionCollection()->add<KToggleAction>("showPhrasebookBar");
+   viewPhrasebookBar->setText(i18n("Show P&hrasebook Bar"));
+   connect(viewPhrasebookBar, SIGNAL(triggered(bool)), this, SLOT(slotViewPhrasebookBar()));
+   viewPhrasebookBar->setToolTip(i18n("Enables/disables the phrasebook bar"));
    viewPhrasebookBar->setWhatsThis (i18n("Enables/disables the phrasebook bar"));
 
-   viewStatusBar = KStdAction::showStatusbar(this, SLOT(slotViewStatusBar()), actionCollection());
-   viewStatusBar->setStatusText(i18n("Enables/disables the statusbar"));
+   viewStatusBar = KStandardAction::showStatusbar(this, SLOT(slotViewStatusBar()), actionCollection());
+   viewStatusBar->setToolTip(i18n("Enables/disables the statusbar"));
    viewStatusBar->setWhatsThis (i18n("Enables/disables the statusbar"));
 
-   configureTTS = new KAction (i18n("&Configure KMouth..."), "configure", 0, this, SLOT(slotConfigureTTS()), actionCollection(), "configureTTS");
-   configureTTS->setStatusText(i18n("Opens the configuration dialog"));
+   configureTTS = actionCollection()->addAction("configureTTS");
+   configureTTS->setIcon(KIcon("configure"));
+   configureTTS->setText(i18n("&Configure KMouth..."));
+   connect(configureTTS, SIGNAL(triggered(bool)), this, SLOT(slotConfigureTTS()));
+   configureTTS->setToolTip(i18n("Opens the configuration dialog"));
    configureTTS->setWhatsThis (i18n("Opens the configuration dialog"));
 
 // The "Help" menu
    // The "Help" menu will automatically get created.
 
 // The popup menu of the list of spoken sentences
-   phraseListSpeak = new KAction (i18n("&Speak"),  "speak",  0, phraseList, SLOT(speakListSelection()),  actionCollection(), "phraselist_speak");
-   phraseListSpeak->setStatusText(i18n("Speaks the currently selected phrases in the history"));
+   phraseListSpeak = actionCollection()->addAction("phraselist_speak");
+   phraseListSpeak->setIcon(KIcon("speak"));
+   phraseListSpeak->setText(i18n("&Speak"));
+   phraseListSpeak->setToolTip(i18n("Speaks the currently selected phrases in the history"));
+   connect(phraseListSpeak, SIGNAL(triggered(bool)), phraseList, SLOT(speakListSelection()));
    phraseListSpeak->setWhatsThis (i18n("Speaks the currently selected phrases in the history"));
 
-   phraseListRemove = new KAction (i18n("&Delete"), "editdelete", 0, phraseList, SLOT(removeListSelection()), actionCollection(), "phraselist_remove");
-   phraseListRemove->setStatusText(i18n("Deletes the currently selected phrases from the history"));
+   phraseListRemove = actionCollection()->addAction("phraselist_remove");
+   phraseListRemove->setIcon(KIcon("edit-delete"));
+   phraseListRemove->setText(i18n("&Delete"));
+   connect(phraseListRemove, SIGNAL(triggered(bool)), phraseList, SLOT(removeListSelection()));
+   phraseListRemove->setToolTip(i18n("Deletes the currently selected phrases from the history"));
    phraseListRemove->setWhatsThis (i18n("Deletes the currently selected phrases from the history"));
 
-   phraseListCut = new KAction (i18n("Cu&t"),   "editcut", 0, phraseList, SLOT(cutListSelection()),    actionCollection(), "phraselist_cut");
-   phraseListCut->setStatusText(i18n("Cuts the currently selected phrases from the history and puts them to the clipboard"));
+   phraseListCut = actionCollection()->addAction("phraselist_cut");
+   phraseListCut->setIcon(KIcon("edit-cut"));
+   phraseListCut->setText(i18n("Cu&t"));
+   connect(phraseListCut, SIGNAL(triggered(bool)), phraseList, SLOT(cutListSelection()));
+   phraseListCut->setToolTip(i18n("Cuts the currently selected phrases from the history and puts them to the clipboard"));
    phraseListCut->setWhatsThis (i18n("Cuts the currently selected phrases from the history and puts them to the clipboard"));
 
-   phraseListCopy   = new KAction (i18n("&Copy"), "editcopy", 0, phraseList, SLOT(copyListSelection()),   actionCollection(), "phraselist_copy");
-   phraseListCut->setStatusText(i18n("Copies the currently selected phrases from the history to the clipboard"));
+   phraseListCopy = actionCollection()->addAction("phraselist_copy");
+   phraseListCopy->setIcon(KIcon("edit-copy"));
+   phraseListCopy->setText(i18n("&Copy"));
+   connect(phraseListCopy, SIGNAL(triggered(bool)), phraseList, SLOT(copyListSelection()));
+   phraseListCut->setToolTip(i18n("Copies the currently selected phrases from the history to the clipboard"));
    phraseListCut->setWhatsThis (i18n("Copies the currently selected phrases from the history to the clipboard"));
 
-   phraselistSelectAll = new KAction (i18n("Select &All Entries"), 0, 0, phraseList, SLOT(selectAllEntries()), actionCollection(),"phraselist_select_all");
-   phraselistSelectAll->setStatusText(i18n("Selects all phrases in the history"));
+   phraselistSelectAll = actionCollection()->addAction("phraselist_select_all");
+   phraselistSelectAll->setText(i18n("Select &All Entries"));
+   connect(phraselistSelectAll, SIGNAL(triggered(bool)), phraseList, SLOT(selectAllEntries()));
+   phraselistSelectAll->setToolTip(i18n("Selects all phrases in the history"));
    phraselistSelectAll->setWhatsThis (i18n("Selects all phrases in the history"));
 
-   phraselistDeselectAll = new KAction (i18n("D&eselect All Entries"), 0, 0, phraseList, SLOT(deselectAllEntries()), actionCollection(),"phraselist_deselect_all");
-   phraselistDeselectAll->setStatusText(i18n("Deselects all phrases in the history"));
+   phraselistDeselectAll = actionCollection()->addAction("phraselist_deselect_all");
+   phraselistDeselectAll->setText(i18n("D&eselect All Entries"));
+   connect(phraselistDeselectAll, SIGNAL(triggered(bool)), phraseList, SLOT(deselectAllEntries()));
+   phraselistDeselectAll->setToolTip(i18n("Deselects all phrases in the history"));
    phraselistDeselectAll->setWhatsThis (i18n("Deselects all phrases in the history"));
 
 // The popup menu of the edit field
@@ -202,7 +254,7 @@ void KMouthApp::initPhraseList()
    setCentralWidget(phraseList);
 }
 
-void KMouthApp::openDocumentFile(const KURL& url)
+void KMouthApp::openDocumentFile(const KUrl& url)
 {
   slotStatusMsg(i18n("Opening file..."));
 
@@ -212,68 +264,74 @@ void KMouthApp::openDocumentFile(const KURL& url)
 
 void KMouthApp::saveOptions() {
    if (isConfigured) {
-      config->setGroup("General Options");
-      config->writeEntry("Geometry", size());
-      config->writeEntry("Show Menubar", viewMenuBar->isChecked());
-      config->writeEntry("Show Toolbar", viewToolBar->isChecked());
-      config->writeEntry("Show Phrasebook Bar", viewPhrasebookBar->isChecked());
-      config->writeEntry("Show Statusbar",viewStatusBar->isChecked());
-      config->writeEntry("ToolBarPos", (int) toolBar("mainToolBar")->barPos());
+      KConfigGroup cg( config, "General Options");
+      cg.writeEntry("Geometry", size());
+      cg.writeEntry("Show Menubar", viewMenuBar->isChecked());
+      // FIXME: Toolbar disabled so it will compile.
+      // cg.writeEntry("Show Toolbar", viewToolBar->isChecked());
+      cg.writeEntry("Show Phrasebook Bar", viewPhrasebookBar->isChecked());
+      cg.writeEntry("Show Statusbar",viewStatusBar->isChecked());
+      // FIXME: KToolBar no longer has barPos() method.
+      // cg.writeEntry("ToolBarPos", (int) toolBar("mainToolBar")->barPos());
 
       if (phraseList != 0)
-         phraseList->saveCompletionOptions(config);
-      optionsDialog->saveOptions(config);
-      toolBar("mainToolBar")->saveSettings (config, "mainToolBar");
-      toolBar("phrasebookBar")->saveSettings (config, "phrasebookBar");
+         phraseList->saveCompletionOptions(config.data());
+      optionsDialog->saveOptions(config.data());
+      cg.changeGroup( "mainToolBar" );
+      toolBar("mainToolBar")->saveSettings( cg );
+      cg.changeGroup( "phrasebookBar");
+      toolBar("phrasebookBar")->saveSettings( cg );
    }
 }
 
 
 void KMouthApp::readOptions()
 {
-  config->setGroup("General Options");
+  KConfigGroup cg( config, "General Options");
 
   // bar status settings
-  bool bViewMenubar = config->readBoolEntry("Show Menubar", true);
+  bool bViewMenubar = cg.readEntry("Show Menubar", true);
   viewMenuBar->setChecked(bViewMenubar);
   slotViewMenuBar();
 
-  bool bViewToolbar = config->readBoolEntry("Show Toolbar", true);
-  viewToolBar->setChecked(bViewToolbar);
-  slotViewToolBar();
+  // FIXME: Toolbar disabled so it will compile.
+  // bool bViewToolbar = cg.readEntry("Show Toolbar", QVariant(true)).toBool();
+  // viewToolBar->setChecked(bViewToolbar);
+  // slotViewToolBar();
 
-  bool bViewPhrasebookbar = config->readBoolEntry("Show Phrasebook Bar", true);
+  bool bViewPhrasebookbar = cg.readEntry("Show Phrasebook Bar", true);
   viewPhrasebookBar->setChecked(bViewPhrasebookbar);
 
-  bool bViewStatusbar = config->readBoolEntry("Show Statusbar", true);
+  bool bViewStatusbar = cg.readEntry("Show Statusbar", true);
   viewStatusBar->setChecked(bViewStatusbar);
   slotViewStatusBar();
 
 
   // bar position settings
-  KToolBar::BarPosition toolBarPos;
-  toolBarPos=(KToolBar::BarPosition) config->readNumEntry("ToolBarPos", KToolBar::Top);
-  toolBar("mainToolBar")->setBarPos(toolBarPos);
+  // FIXME:
+  // KToolBar::BarPosition toolBarPos;
+  // toolBarPos=(KToolBar::BarPosition) cg.readEntry("ToolBarPos", int(KToolBar::Top));
+  // toolBar("mainToolBar")->setBarPos(toolBarPos);
 
-  QSize size=config->readSizeEntry("Geometry");
+  QSize size=cg.readEntry("Geometry",QSize());
   if(!size.isEmpty())
   {
     resize(size);
   }
 
-  optionsDialog->readOptions(config);
+  optionsDialog->readOptions(config.data());
 
-  toolBar("mainToolBar")->applySettings (config, "mainToolBar");
-  toolBar("phrasebookBar")->applySettings (config, "phrasebookBar");
+  toolBar("mainToolBar")->applySettings (config->group( "mainToolBar" ) );
+  toolBar("phrasebookBar")->applySettings (config->group( "phrasebookBar") );
 
-  QString standardBook = KApplication::kApplication()->dirs()->findResource("appdata", "standard.phrasebook");
+  QString standardBook = KGlobal::dirs()->findResource("appdata", "standard.phrasebook");
   if (!standardBook.isEmpty()) {
      PhraseBook book;
-     book.open(KURL::fromPathOrURL( standardBook ));
+     book.open(KUrl::fromPathOrUrl( standardBook ));
      slotPhrasebookConfirmed(book);
   }
   if (phraseList != 0)
-     phraseList->readCompletionOptions(config);
+     phraseList->readCompletionOptions(config.data());
 }
 
 bool KMouthApp::queryClose()
@@ -325,10 +383,15 @@ void KMouthApp::slotFilePrint()
 {
   slotStatusMsg(i18n("Printing..."));
 
-  KPrinter printer;
-  if (printer.setup(this))
+  if (printer == 0) {
+    printer = new QPrinter();
+  }
+
+  QPrintDialog *printDialog = KdePrint::createPrintDialog(printer, this);
+
+  if (printDialog->exec())
   {
-    phraseList->print(&printer);
+    phraseList->print(printer);
   }
 
   slotStatusMsg(i18n("Ready."));
@@ -341,15 +404,19 @@ void KMouthApp::slotFileQuit()
   // close the first window, the list makes the next one the first again.
   // This ensures that queryClose() is called on each window to ask for closing
   KMainWindow* w;
-  if (memberList)
+  if (!memberList().isEmpty())
   {
-    for(w=memberList->first(); w!=0; w=memberList->first())
-    {
+	for (int i = 0; i < memberList().size(); ++i)
+     {
       // only close the window if the closeEvent is accepted. If the user presses Cancel on the saveModified() dialog,
       // the window and the application stay open.
+	w = memberList().at(i);
       if(!w->close())
          break;
-      memberList->removeRef(w);
+#ifdef __GNUC__
+#warning "kde4: how remove it ?.???"
+#endif
+      //memberList()->removeRef(w);
     }
   }
 }
@@ -441,34 +508,28 @@ void KMouthApp::slotStatusMsg(const QString &text)
 {
   ///////////////////////////////////////////////////////////////////
   // change status message permanently
-  statusBar()->clear();
+  statusBar()->clearMessage();
   statusBar()->changeItem(text, ID_STATUS_MSG);
 }
 
 void KMouthApp::slotPhrasebookConfirmed (PhraseBook &book) {
    QString name = "phrasebooks";
-   QPopupMenu *popup = (QPopupMenu *)factory()->container(name, this);
+   QMenu *popup = (QMenu *)factory()->container(name, this);
    KToolBar *toolbar = toolBar ("phrasebookBar");
 
-   KActionPtrList actions = phrases->actions ();
-   KActionPtrList::iterator iter;
-   for (iter = actions.begin(); iter != actions.end(); ++iter) {
-      (*iter)->unplugAll();
-   }
    delete phrases;
-
-   phrases = new KActionCollection (this, actionCollection());
+   phrases = new KActionCollection (actionCollection());
    book.addToGUI (popup, toolbar, phrases, this, SLOT(slotPhraseSelected (const QString &)));
 
-   QString bookLocation = KApplication::kApplication()->dirs()->saveLocation ("appdata", "/");
+   QString bookLocation = KGlobal::dirs()->saveLocation ("appdata", "/");
    if (!bookLocation.isNull() && !bookLocation.isEmpty()) {
-      book.save (KURL::fromPathOrURL( bookLocation + "standard.phrasebook" ));
+      book.save (KUrl::fromPathOrUrl( bookLocation + "standard.phrasebook" ));
    }
 }
 
 void KMouthApp::slotConfigurationChanged()
 {
-   optionsDialog->saveOptions (config);
+   optionsDialog->saveOptions (config.data());
 }
 
 void KMouthApp::slotPhraseSelected (const QString &phrase) {
