@@ -1,7 +1,7 @@
 /***************************************************** vim:set ts=4 sw=4 sts=4:
   This file is the templates for the configuration plug ins.
   -------------------
-  Copyright : (C) 2002-2003 by José Pablo Ezequiel "Pupeno" Fernández
+  Copyright : (C) 2002-2003 by José Pablo Ezequiel "Pupeno" Fernández <pupeno@kde.org>
   -------------------
   Original author: José Pablo Ezequiel "Pupeno" Fernández <pupeno@kde.org>
   Current Maintainer: Gary Cramblitt <garycramblitt@comcast.net>
@@ -11,36 +11,40 @@
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; version 2 of the License.               *
+ *   the Free Software Foundation; version 2 of the License or             *
+ *   (at your option) version 3.                                           *
  *                                                                         *
  ***************************************************************************/
 
+// PluginConf includes.
+#include "pluginconf.h"
+#include "pluginconf.moc"
+
 // C++ library includes.
 #include <stdlib.h>
 #include <sys/param.h>
 
 // Qt includes.
-#include <qfile.h>
-#include <qfileinfo.h>
-#include <qstring.h>
+#include <QFile>
+#include <QFileInfo>
+
+//Added by qt3to4:
+#include <QTextStream>
 
 // KDE includes.
 #include <kglobal.h>
 #include <klocale.h>
 #include <kstandarddirs.h>
 
-// PluginConf includes.
-#include "pluginconf.h"
-#include "pluginconf.moc"
-
 /**
 * Constructor 
 */
-PlugInConf::PlugInConf( QWidget *parent, const char *name) : QWidget(parent, name){
-    kdDebug() << "PlugInConf::PlugInConf: Running" << endl;
-    QString systemPath(getenv("PATH"));
-    // kdDebug() << "Path is " << systemPath << endl;
-    m_path = QStringList::split(":", systemPath);
+PlugInConf::PlugInConf( QWidget *parent, const char *name) : QWidget(parent){
+    setObjectName(name);
+    kDebug() << "PlugInConf::PlugInConf: Running";
+    QString systemPath(qgetenv("PATH"));
+    // kDebug() << "Path is " << systemPath;
+    m_path = systemPath.split( ':');
     m_player = 0;
 }
 
@@ -48,7 +52,7 @@ PlugInConf::PlugInConf( QWidget *parent, const char *name) : QWidget(parent, nam
 * Destructor.
 */
 PlugInConf::~PlugInConf(){
-    kdDebug() << "PlugInConf::~PlugInConf: Running" << endl;
+    kDebug() << "PlugInConf::~PlugInConf: Running";
     delete m_player;
 }
 
@@ -66,7 +70,7 @@ PlugInConf::~PlugInConf(){
 *                    loading your configuration.
 */
 void PlugInConf::load(KConfig* /*config*/, const QString& /*configGroup*/){
-    kdDebug() << "PlugInConf::load: Running" << endl;
+    kDebug() << "PlugInConf::load: Running";
 }
 
 /**
@@ -80,7 +84,7 @@ void PlugInConf::load(KConfig* /*config*/, const QString& /*configGroup*/){
 *                    saving your configuration.
 */
 void PlugInConf::save(KConfig* /*config*/, const QString& /*configGroup*/){
-    kdDebug() << "PlugInConf::save: Running" << endl;
+    kDebug() << "PlugInConf::save: Running";
 }
 
 /** 
@@ -91,7 +95,7 @@ void PlugInConf::save(KConfig* /*config*/, const QString& /*configGroup*/){
 * be applied to the on-screen widgets; not to the config file.
 */
 void PlugInConf::defaults(){
-    kdDebug() << "PlugInConf::defaults: Running" << endl;
+    kDebug() << "PlugInConf::defaults: Running";
 }
 
 /**
@@ -109,7 +113,7 @@ bool PlugInConf::supportsMultiInstance() { return true; }
 * This function informs the plugin of the desired language to be spoken
 * by the plugin.  The plugin should attempt to adapt itself to the
 * specified language code, choosing sensible defaults if necessary.
-* If the passed-in code is QString::null, no specific language has
+* If the passed-in code is QString(), no specific language has
 * been chosen.
 * @param lang        The desired language code or Null if none.
 *
@@ -121,10 +125,10 @@ void PlugInConf::setDesiredLanguage(const QString& /*lang*/ ) { }
 * Return fully-specified talker code for the configured plugin.  This code
 * uniquely identifies the configured instance of the plugin and distinquishes
 * one instance from another.  If the plugin has not been fully configured,
-* i.e., cannot yet synthesize, return QString::null.
+* i.e., cannot yet synthesize, return QString().
 * @return            Fully-specified talker code.
 */
-QString PlugInConf::getTalkerCode() { return QString::null; }
+QString PlugInConf::getTalkerCode() { return QString(); }
 
 /**
 * Return a list of all the languages currently supported by the plugin.
@@ -153,23 +157,23 @@ QString PlugInConf::getLocation(const QString &name) {
     QFileInfo fileinfo(name);
     if (fileinfo.isFile() || (fileinfo.isSymLink() && QFileInfo(fileinfo.readLink()).isFile()))
         return name;
-    kdDebug() << "PluginConf::getLocation: Searching for " << name << " in the path.." << endl;
-    kdDebug() << m_path << endl;
+    kDebug() << "PluginConf::getLocation: Searching for " << name << " in the path..";
+    kDebug() << m_path;
     for(QStringList::iterator it = m_path.begin(); it != m_path.end(); ++it) {
         QString fullName = *it;
 
-        fullName += "/";
+        fullName += '/';
         fullName += name;
         fileinfo.setFile(fullName);
         // The user either has the directory of the file in the path...
         if(fileinfo.isFile() || fileinfo.isSymLink() && QFileInfo(fileinfo.readLink()).isFile()) {
             return fullName;
-//             kdDebug() << "PluginConf:getLocation: " << fullName << endl;
+//             kDebug() << "PluginConf:getLocation: " << fullName;
         }
         // ....Or the file itself in the path (slightly freaky but hey.)
-        else if(QFileInfo(*it).baseName().append(QString(".").append(QFileInfo(*it).extension())) == name) {
+        else if(QFileInfo(*it).baseName().append(QString(".").append(QFileInfo(*it).suffix())) == name) {
             return fullName;
-//             kdDebug() << "PluginConf:getLocation: " << fullName << endl;
+//             kDebug() << "PluginConf:getLocation: " << fullName;
         }
     }
     return "";
@@ -185,8 +189,9 @@ QString PlugInConf::splitLanguageCode(const QString& languageCode, QString& coun
 {
     QString locale = languageCode;
     QString langCode;
+    QString modifier;
     QString charSet;
-    KGlobal::locale()->splitLocale(locale, langCode, countryCode, charSet);
+    KGlobal::locale()->splitLocale(locale, langCode, countryCode, modifier, charSet);
     return langCode;
 }
 
@@ -205,17 +210,17 @@ QString PlugInConf::splitLanguageCode(const QString& languageCode, QString& coun
 
 /*static*/ QString PlugInConf::testMessage(const QString& languageCode)
 {
-    QString key = "Name[" + languageCode + "]";
+    QString key = "Name[" + languageCode + ']';
     QString result;
     QString def;
-    QFile file(locate("data", "kttsd/kcmkttsd_testmessage.desktop"));
-    if (file.open(IO_ReadOnly))
+    QFile file(KStandardDirs::locate("data", "kttsd/kcmkttsd_testmessage.desktop"));
+    if (file.open(QIODevice::ReadOnly))
     {
         QTextStream stream(&file);
-        stream.setEncoding(QTextStream::UnicodeUTF8);
+        stream.setCodec("UTF-8");
         while ( !stream.atEnd() ) {
             QString line = stream.readLine(); // line of text excluding '\n'
-            QStringList keyAndValue = QStringList::split("=", line);
+            QStringList keyAndValue = line.split( '=');
             if (keyAndValue.count() == 2)
             {
                 if (keyAndValue[0] == key)
